# -- coding: utf-8 --
from graphics_and_games_klassen import Figur, Rechteck

        
class Dancefloor:
    """
    Klasse zur Beschreibung des Dancefloors
    """
    def __init__(self):
        """
        Konstruktor des Dancefloors legt die Leuchten an
        """
        self.breite = 40
        self.spaltenanzahl = 19
        self.zeilenanzahl = 19
        self.leuchten = [[Rechteck() for _ in range(self.zeilenanzahl)] for _ in range(self.spaltenanzahl)]
        self.farben = [["" for _ in range(self.zeilenanzahl)] for _ in range(self.spaltenanzahl)]
        
        farbe = "blau"
        for spalte in range(self.spaltenanzahl):
            for zeile in range(self.zeilenanzahl):
                self.leuchten[spalte][zeile].GroesseSetzen(self.breite, self.breite)
                self.leuchten[spalte][zeile].PositionSetzen(spalte * self.breite, zeile * self.breite)
                
                if farbe == "blau":
                    farbe = "rot"
                else:
                    farbe = "blau"
                
                self.FarbeSetzen(spalte, zeile, farbe)
                self.farben[spalte][zeile] = farbe

    def FarbeSetzen(self, spalte, zeile, farbe):
        """
        Setzt die angegebene Leuchte auf die gewünschte Farbe
        :param spalte: die Spaltennummer der Leuchte
        :param zeile: die Zeilennummer der Leuchte
        :param farbe: die gewünschte Farbe
        """
        self.leuchten[spalte][zeile].FarbeSetzen(farbe)
        self.farben[spalte][zeile] = farbe

    def FarbeGeben(self, spalte, zeile):
        """
        Gibt die Farbe der angegebene Leuchte
        :param spalte: die Spaltennummer der Leuchte
        :param zeile: die Zeilennummer der Leuchte
        :return: die Farbe der gewünschten Leuchte
        """
        return self.farben[spalte][zeile]

    def SpaltenanzahlGeben(self):
        """
        Meldet die Anzahl der Spalten
        :return: Spaltenanzahl
        """
        return self.spaltenanzahl

    def ZeilenanzahlGeben(self):
        """
        Meldet die Anzahl der Zeilen
        :return: Zeilenanzahl
        """
        return self.zeilenanzahl


import random

class DancefloorSteuerung(Figur):
    """
    Steuerung der Leuchten auf dem Dancefloor
    """
    def __init__(self):
        """
        Legt den Tanzboden und den Zufallsgenerator an.
        """
        super().__init__()
        self.d = Dancefloor()
        self.zufallszahlgenerator = random.Random()

    def AktionAusfuehren(self): 
        """
        Lässt die Farben laufen
        """
        for spalte in range(self.d.SpaltenanzahlGeben() - 1, 0, -1):
            for zeile in range(self.d.ZeilenanzahlGeben()):
                self.d.FarbeSetzen(spalte, zeile, self.d.FarbeGeben(spalte - 1, zeile))
        
        for zeile in range(self.d.ZeilenanzahlGeben()):
            self.d.FarbeSetzen(0, zeile, self.ZufälligeFarbeGeben())

    def ZufälligeFarbeGeben(self):
        """
        Bestimmt eine zufällige Farbe
        :return: zufällige Farbe
        """
        zufallszahl = self.zufallszahlgenerator.randint(1, 12)
        if zufallszahl == 1:
            return "weiß"
        elif zufallszahl == 2:
            return "rot"
        elif zufallszahl == 3:
            return "grün"
        elif zufallszahl == 4:
            return "blau"
        elif zufallszahl == 5:
            return "gelb"
        elif zufallszahl == 6:
            return "magenta"
        elif zufallszahl == 7:
            return "cyan"
        elif zufallszahl == 8:
            return "hellgelb"
        elif zufallszahl == 9:
            return "hellgrün"
        elif zufallszahl == 10:
            return "orange"
        elif zufallszahl == 11:
            return "braun"
        elif zufallszahl == 12:
            return "grau"
        else:
            return "schwarz"


DancefloorSteuerung()
