# -- coding: utf-8 --
"""
Created on Wed Apr  8 17:53:04 2020
@author: Klaus Reinold
"""

from graphics_and_games_klassen import Figur, Text, Rechteck
from intern.zeichenfenster import Zeichenfenster

class Zelle(Rechteck):
    """
    Der Zaun als Hindernis.
    """
    
    def __init__(self, xLinksOben, yLinksOben, farbeNeu):
        """
        Platziert eine Zelle
        """    
        super().__init__()
        self.PositionSetzen(xLinksOben, yLinksOben)
        self.GroesseSetzen(46, 46)
        self.FarbeSetzen(farbeNeu)
        
class Blume(Figur):
    """
    Blume, die darauf wartet, gesammelt zu werden.
    """
    
    def __init__(self, xNeu = 4, yNeu = 2):
       """
       Der Konstruktor2 erzeugt eine Blume in einem Spielfeld mit 10x10 Zellen.
       --Parameter xNeu  x-Position der Blume
       --Parameter yNeu  y-Position der Blume
       """    
       super().__init__()
       self.FigurteilFestlegenEllipse(0, 0, 25, 25, "gelb")
       self.FigurteilFestlegenEllipse(0, -20, 20, 20, "weiss")
       self.FigurteilFestlegenEllipse(20, -10, 20, 20, "weiss")
       self.FigurteilFestlegenEllipse(20, 10, 20, 20, "weiss")
       self.FigurteilFestlegenEllipse(0, 20, 20, 20, "weiss")
       self.FigurteilFestlegenEllipse(-20, -10, 20, 20, "weiss")
       self.FigurteilFestlegenEllipse(-20, 10, 20, 20, "weiss")
       self.GanzNachVornBringen()
       if(xNeu<10 and xNeu>=0 and yNeu<10 and yNeu>=0):
             self.PositionSetzen(xNeu*50 +25, yNeu*50 +25)
             
    def GepfluecktWerden(self):
        """
        Die Blume verschwindet, wenn sie gepflückt wurde.
        """
        if self.BeruehrtFarbe("orange"):
            self.Entfernen()
            
    def AktionAusfuehren(self):
        self.GepfluecktWerden()
        
class Fliegenpilz(Figur):
    """
    Fliegenpilz, der darauf wartet, gesammelt zu werden.
    """
    
    def __init__(self, xneu = 6, yneu = 2):
        """
        Dieser Konstruktor erzeugt einen Fliegenpilz an einer bestimmten Position. 
        """
        super().__init__()
        self.FigurteilFestlegenRechteck(-10, 10, 20, 40, "weiss")
        self.FigurteilFestlegenEllipse(-45, -10, 90, 30, "rot")   
        self.PositionSetzen(xneu*50 +25, yneu*50 +25)
        self.GanzNachVornBringen()
        
    def GepflücktWerden(self):
        """
        Der Fliegenpilz verschwindet, wenn er berührt wurde.
        """
        if self.BeruehrtFarbe("orange"):
            self.Entfernen()
            
    def AktionAusfuehren(self):
        """
        Aktion zur Überprüfung des Gepflücktwerdens
        """
        self.GepflücktWerden()
        
class Florian(Figur):
    """
    Die Spielfigur der Blumenwelt.
    Attribute:
    -- gesammelteBlumen Blumen, die gesammelt wurden
    -- schritte Anzahl der Schritte, die Florian geht
    """
    
    def __init__(self):
        """
        Legt die Form und die Startposition fest.
        """    
        super().__init__()
        self.FigurteilFestlegenRechteck(-20, -15, 40, 60, "orange")
        self.FigurteilFestlegenEllipse(-10, -50, 20, 30, "orange")
        self.FigurteilFestlegenDreieck(0, 0, 0, 30, 18, 15, "gelb")
        self.PositionSetzen(75, 125)
        self.GanzNachVornBringen()
        self.gesammelteBlumen = 0
        self.schritte = 0
        
    def Gehen(self):
        """
        Florian geht einen Schritt in Blickrichtung.
        """
        
        if self.WinkelGeben()==0:      
            self.NachOstenGehen()     
        elif self.WinkelGeben()==90:          
            self.NachNordenGehen()         
        elif self.WinkelGeben()==180:
            self.NachWestenGehen()
        elif self.WinkelGeben()==270:
            self.NachSuedenGehen()
        self.schritte = self.schritte + 1
        
    def NachOstenGehen(self):
        """
        Lässt Florian eine Zelle nach Osten gehen.
        """    
        if self.XPositionGeben()<450:       
            self.PositionSetzen(self.XPositionGeben()+50, self.YPositionGeben())
            
    def NachWestenGehen(self):
        """
        Lässt Florian eine Zelle nach Westen gehen.
        """    
        if self.XPositionGeben()>50:
            self.PositionSetzen(self.XPositionGeben()-50, self.YPositionGeben())
            
    def NachSuedenGehen(self):
        """
        Lässt Florian eine Zelle nach Süden gehen.
        """  
        if self.YPositionGeben()<450:
            self.PositionSetzen(self.XPositionGeben(), self.YPositionGeben()+50)
            
    def NachNordenGehen(self):
        """
        Lässt Florian eine Zelle nach Norden gehen.
        """
        if self.YPositionGeben()>50:
            self.PositionSetzen(self.XPositionGeben(), self.YPositionGeben()-50)
            
    def LinksDrehen(self):
        """
        Dreht sich um 90 Grad nach links
        Tipp: Teste vorab (an einem Objekt der Klasse Florian) 
        die Methoden Drehen, WinkelGeben, WinkelSetzen der Oberklasse
        """    
        if self.WinkelGeben()==0:
            self.WinkelSetzen(90)      
        elif self.WinkelGeben()==90:          
            self.WinkelSetzen(180)         
        elif self.WinkelGeben()==180:               
            self.WinkelSetzen(270)            
        elif self.WinkelGeben()==270:              
            self.WinkelSetzen(0)
            
    def RechtsDrehen(self):
        """
        Dreht sich um 90 Grad nach rechts
        Tipp: Teste vorab (an einem Objekt der Klasse Florian) 
        die Methoden Drehen, WinkelGeben, WinkelSetzen der Oberklasse
        """    
        if self.WinkelGeben()==0:   
            self.WinkelSetzen(270)    
        elif self.WinkelGeben()==90: 
            self.WinkelSetzen(0)        
        elif self.WinkelGeben()==180:       
            self.WinkelSetzen(90)   
        elif self.WinkelGeben()==270:           
            self.WinkelSetzen(180)
            
    def Pfluecken(self):
        """
        Pflückt eine Blume, falls auf der Zelle vorhanden.
        """
        if self.BeruehrtFarbe("gelb"):
            self.gesammelteBlumen = self.gesammelteBlumen+1
            
    def TasteGedrueckt(self, taste):
        """
        Steuerung der Figur: Links-/Rechtsdrehen über Cursortasten.
        """
        if taste == "right":       
            self.RechtsDrehen()   
        elif taste == "left":          
            self.LinksDrehen()
            
    def AktionAusfuehren(self):
        """
        Ständige Bewegung, außer Florian ist an der Grenze seiner Welt.
        """    
        self.Gehen()
        self.Pfluecken()
        print("Schritte " + str(self.schritte) + " Blumen " + str(self.gesammelteBlumen))
        if self.gesammelteBlumen == 10:
            Zeichenfenster().Pausieren()
            
class Blumenwelt:
    """
    Legt die Blumenwelt an und die nicht beweglichen Objekte. 
    """
    
    def __init__(self):
        """
        Baut das Szenario auf.
        """    
        #Diesen Abschnitt ignorieren, es werden die 10x10 Zellen der Welt erzeugt und positioniert
        for zellenNummerX in range(0, 10):
            for zellenNummerY in range(0, 10):
                Zelle(50*zellenNummerX+2, 50*zellenNummerY+2, "grün")
        #Abschnittsende
        Florian()
        nummer = 2 # Nummer ist ein Platzhalter für eine Zahl. Startwert 2 für die Nummer
        while (nummer < 6):
            Blume(nummer, 3)
            nummer = nummer +1 # die Nummer wird um eins erhöht
        Blume(1, 2)
        Blume(7, 4)
        Blume(7, 6)
        Blume(9, 7)
        Blume(3, 8)
        Blume(8, 9)
        
Blumenwelt()
